@@ -2,6 +2,7 @@ import os
 
 from pathlib import Path
 
+from ats_base.common import func
 from ats_case.case.context import Context
 from ats_case.common.enum import OperationClazz
 
@@ -38,9 +39,7 @@ class Translator(object):
             return steps
 
     def _script(self):
-        root_dir = os.environ.get('TCC')
-
-        user_dir = os.path.join(root_dir, 'script', 'debug', self._context.tester.username)
+        user_dir = func.makeDir(os.environ.get('PROJECT_DIR'), 'script', 'debug', self._context.tester.username)
         script_file = os.path.join(user_dir, 'steps.py')
 
         if not os.path.exists(user_dir):
